@@ -10,7 +10,7 @@ from ..utils import check_spark, check_options
 spark = check_spark()
 
 
-def fromrdd(rdd, nrecords=None, shape=None, index=None, labels=None, dtype=None):
+def fromrdd(rdd, nrecords=None, shape=None, index=None, labels=None, dtype=None, ordered=False):
     """
     Load series data from a Spark RDD.
 
@@ -37,6 +37,9 @@ def fromrdd(rdd, nrecords=None, shape=None, index=None, labels=None, dtype=None)
 
     dtype : string, default = None
         Data numerical type (if provided will avoid check)
+
+    ordered : boolean, optional, default = False
+        Whether or not the rdd is ordered by key
     """
     from .series import Series
     from bolt.spark.array import BoltArraySpark
@@ -65,7 +68,7 @@ def fromrdd(rdd, nrecords=None, shape=None, index=None, labels=None, dtype=None)
             k = (k,)
         return k, v
 
-    values = BoltArraySpark(rdd.map(process_keys), shape=shape, dtype=dtype, split=len(shape)-1)
+    values = BoltArraySpark(rdd.map(process_keys), shape=shape, dtype=dtype, split=len(shape)-1, ordered=ordered)
     return Series(values, index=index, labels=labels)
 
 def fromarray(values, index=None, labels=None, npartitions=None, engine=None):
@@ -115,6 +118,7 @@ def fromarray(values, index=None, labels=None, npartitions=None, engine=None):
     if spark and isinstance(engine, spark):
         axis = tuple(range(values.ndim - 1))
         values = bolt.array(values, context=engine, npartitions=npartitions, axis=axis)
+        values._ordered = True
         return Series(values, index=index)
 
     return Series(values, index=index, labels=labels)
@@ -161,7 +165,7 @@ def fromlist(items, accessor=None, index=None, labels=None, dtype=None, npartiti
         rdd = engine.parallelize(items, npartitions)
         if accessor:
             rdd = rdd.mapValues(accessor)
-        return fromrdd(rdd, nrecords=nrecords, index=index, labels=labels, dtype=dtype)
+        return fromrdd(rdd, nrecords=nrecords, index=index, labels=labels, dtype=dtype, ordered=True)
 
     else:
         if accessor:
@@ -227,7 +231,7 @@ def fromtext(path, ext='txt', dtype='float64', skip=0, shape=None, index=None, l
             return (idx,), ary
 
         rdd = data.zipWithIndex().map(switch)
-        return fromrdd(rdd, dtype=str(dtype), shape=shape, index=index)
+        return fromrdd(rdd, dtype=str(dtype), shape=shape, index=index, ordered=True)
 
     else:
         reader = get_parallel_reader(path)(engine, credentials=credentials)
@@ -311,7 +315,7 @@ def frombinary(path, ext='bin', conf='conf.json', dtype=None, shape=None, skip=0
         if not index:
             index = arange(shape[-1])
 
-        return fromrdd(rdd, dtype=dtype, shape=shape, index=index)
+        return fromrdd(rdd, dtype=dtype, shape=shape, index=index, ordered=True)
 
     else:
         reader = get_parallel_reader(path)(engine, credentials=credentials)
